@@ -6,12 +6,15 @@ mod bitfinex_spot {
     use crypto_ws_client::{BitfinexWSClient, WSClient};
     use std::sync::mpsc::{Receiver, Sender};
 
-    #[test]
-    fn subscribe() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe() {
         gen_test_code!(
             BitfinexWSClient,
             subscribe,
-            &vec!["trades:tBTCUST".to_string(), "trades:tETHUST".to_string()]
+            &vec![
+                ("trades".to_string(), "tBTCUST".to_string()),
+                ("trades".to_string(), "tETHUST".to_string()),
+            ]
         );
     }
 
@@ -21,12 +24,12 @@ mod bitfinex_spot {
         gen_test_code!(
             BitfinexWSClient,
             subscribe,
-            &vec!["trades:tXXXYYY".to_string()]
+            &vec![("trades".to_string(), "tXXXYYY".to_string())]
         );
     }
 
-    #[test]
-    fn subscribe_trade() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_trade() {
         gen_test_code!(
             BitfinexWSClient,
             subscribe_trade,
@@ -34,8 +37,8 @@ mod bitfinex_spot {
         );
     }
 
-    #[test]
-    fn subscribe_ticker() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_ticker() {
         gen_test_code!(
             BitfinexWSClient,
             subscribe_ticker,
@@ -43,8 +46,8 @@ mod bitfinex_spot {
         );
     }
 
-    #[test]
-    fn subscribe_bbo() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_bbo() {
         gen_test_code!(
             BitfinexWSClient,
             subscribe_bbo,
@@ -52,8 +55,8 @@ mod bitfinex_spot {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook() {
         gen_test_code!(
             BitfinexWSClient,
             subscribe_orderbook,
@@ -61,8 +64,8 @@ mod bitfinex_spot {
         );
     }
 
-    #[test]
-    fn subscribe_l3_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_l3_orderbook() {
         gen_test_code!(
             BitfinexWSClient,
             subscribe_l3_orderbook,
@@ -70,8 +73,8 @@ mod bitfinex_spot {
         );
     }
 
-    #[test]
-    fn subscribe_candlestick() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_candlestick() {
         gen_test_subscribe_candlestick!(BitfinexWSClient, &vec![("tBTCUST".to_string(), 60)]);
         gen_test_subscribe_candlestick!(BitfinexWSClient, &vec![("tBTCUST".to_string(), 2592000)]);
     }
@@ -82,17 +85,17 @@ mod bitfinex_swap {
     use crypto_ws_client::{BitfinexWSClient, WSClient};
     use std::sync::mpsc::{Receiver, Sender};
 
-    #[test]
-    fn subscribe() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe() {
         gen_test_code!(
             BitfinexWSClient,
             subscribe,
-            &vec!["trades:tBTCF0:USTF0".to_string()]
+            &vec![("trades".to_string(), "tBTCF0:USTF0".to_string())]
         );
     }
 
-    #[test]
-    fn subscribe_trade() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_trade() {
         gen_test_code!(
             BitfinexWSClient,
             subscribe_trade,
@@ -100,8 +103,8 @@ mod bitfinex_swap {
         );
     }
 
-    #[test]
-    fn subscribe_ticker() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_ticker() {
         gen_test_code!(
             BitfinexWSClient,
             subscribe_ticker,
@@ -109,8 +112,8 @@ mod bitfinex_swap {
         );
     }
 
-    #[test]
-    fn subscribe_bbo() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_bbo() {
         gen_test_code!(
             BitfinexWSClient,
             subscribe_bbo,
@@ -118,8 +121,8 @@ mod bitfinex_swap {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook() {
         gen_test_code!(
             BitfinexWSClient,
             subscribe_orderbook,
@@ -127,8 +130,8 @@ mod bitfinex_swap {
         );
     }
 
-    #[test]
-    fn subscribe_l3_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_l3_orderbook() {
         gen_test_code!(
             BitfinexWSClient,
             subscribe_l3_orderbook,
@@ -136,8 +139,8 @@ mod bitfinex_swap {
         );
     }
 
-    #[test]
-    fn subscribe_candlestick() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_candlestick() {
         gen_test_subscribe_candlestick!(BitfinexWSClient, &vec![("tBTCF0:USTF0".to_string(), 60)]);
         gen_test_subscribe_candlestick!(
             BitfinexWSClient,
