@@ -4,12 +4,15 @@ use std::sync::mpsc::{Receiver, Sender};
 #[macro_use]
 mod utils;
 
-#[test]
-fn subscribe() {
+#[tokio::test(flavor = "multi_thread")]
+async fn subscribe() {
     gen_test_code!(
         BithumbWSClient,
         subscribe,
-        &vec!["TRADE:BTC-USDT".to_string(), "TRADE:ETH-USDT".to_string()]
+        &vec![
+            ("TRADE".to_string(), "BTC-USDT".to_string()),
+            ("TRADE".to_string(), "ETH-USDT".to_string()),
+        ]
     );
 }
 
@@ -19,21 +22,21 @@ fn subscribe_illegal_symbol() {
     gen_test_code!(
         BithumbWSClient,
         subscribe,
-        &vec!["TRADE:XXX-YYY".to_string(),]
+        &vec![("TRADE".to_string(), "XXX-YYY".to_string())]
     );
 }
 
-#[test]
-fn subscribe_raw_json() {
+#[tokio::test(flavor = "multi_thread")]
+async fn subscribe_raw_json() {
     gen_test_code!(
         BithumbWSClient,
-        subscribe,
+        send,
         &vec![r#"{"cmd":"subscribe","args":["TRADE:BTC-USDT","TRADE:ETH-USDT"]}"#.to_string()]
     );
 }
 
-#[test]
-fn subscribe_trade() {
+#[tokio::test(flavor = "multi_thread")]
+async fn subscribe_trade() {
     gen_test_code!(
         BithumbWSClient,
         subscribe_trade,
@@ -41,8 +44,8 @@ fn subscribe_trade() {
     );
 }
 
-#[test]
-fn subscribe_orderbook() {
+#[tokio::test(flavor = "multi_thread")]
+async fn subscribe_orderbook() {
     gen_test_code!(
         BithumbWSClient,
         subscribe_orderbook,
