@@ -4,29 +4,31 @@ mod utils;
 #[cfg(test)]
 mod bitz_spot {
     use crypto_ws_client::{BitzSpotWSClient, WSClient};
-    use std::sync::mpsc::{Receiver, Sender};
-    use std::time::{SystemTime, UNIX_EPOCH};
+    use std::{
+        sync::mpsc::{Receiver, Sender},
+        time::{SystemTime, UNIX_EPOCH},
+    };
 
-    #[test]
+    #[tokio::test(flavor = "multi_thread")]
     #[ignore = "bitz.com has shutdown since October 2021"]
-    fn subscribe() {
+    async fn subscribe() {
         gen_test_code!(
             BitzSpotWSClient,
             subscribe,
             &vec![
-                "market:btc_usdt".to_string(),
-                "depth:btc_usdt".to_string(),
-                "order:btc_usdt".to_string()
+                ("market".to_string(), "btc_usdt".to_string()),
+                ("depth".to_string(), "btc_usdt".to_string()),
+                ("order".to_string(), "btc_usdt".to_string()),
             ]
         );
     }
 
-    #[test]
+    #[tokio::test(flavor = "multi_thread")]
     #[ignore = "bitz.com has shutdown since October 2021"]
-    fn subscribe_raw_json() {
+    async fn subscribe_raw_json() {
         gen_test_code!(
             BitzSpotWSClient,
-            subscribe,
+            send,
             &vec![format!(
                 r#"{{"action":"Topic.sub", "data":{{"symbol":"btc_usdt", "type":"market,depth,order", "_CDID":"100002", "dataType":"1"}}, "msg_id":{}}}"#,
                 SystemTime::now()
@@ -37,9 +39,9 @@ mod bitz_spot {
         );
     }
 
-    #[test]
+    #[tokio::test(flavor = "multi_thread")]
     #[ignore = "bitz.com has shutdown since October 2021"]
-    fn subscribe_trade() {
+    async fn subscribe_trade() {
         gen_test_code!(
             BitzSpotWSClient,
             subscribe_trade,
@@ -47,9 +49,9 @@ mod bitz_spot {
         );
     }
 
-    #[test]
+    #[tokio::test(flavor = "multi_thread")]
     #[ignore = "bitz.com has shutdown since October 2021"]
-    fn subscribe_orderbook() {
+    async fn subscribe_orderbook() {
         gen_test_code!(
             BitzSpotWSClient,
             subscribe_orderbook,
@@ -57,9 +59,9 @@ mod bitz_spot {
         );
     }
 
-    #[test]
+    #[tokio::test(flavor = "multi_thread")]
     #[ignore = "bitz.com has shutdown since October 2021"]
-    fn subscribe_ticker() {
+    async fn subscribe_ticker() {
         gen_test_code!(
             BitzSpotWSClient,
             subscribe_ticker,
@@ -67,9 +69,9 @@ mod bitz_spot {
         );
     }
 
-    #[test]
+    #[tokio::test(flavor = "multi_thread")]
     #[ignore = "bitz.com has shutdown since October 2021"]
-    fn subscribe_candlestick() {
+    async fn subscribe_candlestick() {
         gen_test_subscribe_candlestick!(BitzSpotWSClient, &vec![("btc_usdt".to_string(), 60)]);
         gen_test_subscribe_candlestick!(BitzSpotWSClient, &vec![("btc_usdt".to_string(), 2592000)]);
     }
