@@ -4,15 +4,15 @@ use std::sync::mpsc::{Receiver, Sender};
 #[macro_use]
 mod utils;
 
-#[test]
-fn deribit_all_trades() {
+#[tokio::test(flavor = "multi_thread")]
+async fn deribit_all_trades() {
     gen_test_code!(
         DeribitWSClient,
         subscribe,
         // https://docs.deribit.com/?javascript#trades-kind-currency-interval
         &vec![
-            "trades.future.any.100ms".to_string(),
-            "trades.option.any.100ms".to_string(),
+            ("trades.future.SYMBOL.100ms".to_string(), "any".to_string()),
+            ("trades.option.SYMBOL.100ms".to_string(), "any".to_string()),
         ]
     );
 }
@@ -22,26 +22,27 @@ mod deribit_inverse_future {
     use crypto_ws_client::{DeribitWSClient, WSClient};
     use std::sync::mpsc::{Receiver, Sender};
 
-    #[test]
-    fn subscribe() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe() {
         gen_test_code!(
             DeribitWSClient,
             subscribe,
-            &vec!["trades.future.BTC.100ms".to_string()]
+            &vec![("trades.future.SYMBOL.100ms".to_string(), "BTC".to_string())]
         );
     }
 
-    #[test]
-    fn subscribe_trade() {
+    #[ignore = "lack of liquidity"]
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_trade() {
         gen_test_code!(
             DeribitWSClient,
             subscribe_trade,
-            &vec!["BTC-25MAR22".to_string(), "BTC-24JUN22".to_string()]
+            &vec!["BTC-29APR22".to_string(), "BTC-24JUN22".to_string()]
         );
     }
 
-    #[test]
-    fn subscribe_ticker() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_ticker() {
         gen_test_code!(
             DeribitWSClient,
             subscribe_ticker,
@@ -49,8 +50,8 @@ mod deribit_inverse_future {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook() {
         gen_test_code!(
             DeribitWSClient,
             subscribe_orderbook,
@@ -58,8 +59,8 @@ mod deribit_inverse_future {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook_topk() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook_topk() {
         gen_test_code!(
             DeribitWSClient,
             subscribe_orderbook_topk,
@@ -67,8 +68,8 @@ mod deribit_inverse_future {
         );
     }
 
-    #[test]
-    fn subscribe_candlestick() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_candlestick() {
         gen_test_subscribe_candlestick!(DeribitWSClient, &vec![("BTC-24JUN22".to_string(), 60)]);
         gen_test_subscribe_candlestick!(DeribitWSClient, &vec![("BTC-24JUN22".to_string(), 86400)]);
     }
@@ -79,17 +80,20 @@ mod deribit_inverse_swap {
     use crypto_ws_client::{DeribitWSClient, WSClient};
     use std::sync::mpsc::{Receiver, Sender};
 
-    #[test]
-    fn subscribe() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe() {
         gen_test_code!(
             DeribitWSClient,
             subscribe,
-            &vec!["trades.BTC-PERPETUAL.100ms".to_string()]
+            &vec![(
+                "trades.SYMBOL.100ms".to_string(),
+                "BTC-PERPETUAL".to_string()
+            )]
         );
     }
 
-    #[test]
-    fn subscribe_trade() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_trade() {
         gen_test_code!(
             DeribitWSClient,
             subscribe_trade,
@@ -97,8 +101,8 @@ mod deribit_inverse_swap {
         );
     }
 
-    #[test]
-    fn subscribe_ticker() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_ticker() {
         gen_test_code!(
             DeribitWSClient,
             subscribe_ticker,
@@ -106,8 +110,8 @@ mod deribit_inverse_swap {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook() {
         gen_test_code!(
             DeribitWSClient,
             subscribe_orderbook,
@@ -115,8 +119,8 @@ mod deribit_inverse_swap {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook_topk() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook_topk() {
         gen_test_code!(
             DeribitWSClient,
             subscribe_orderbook_topk,
@@ -124,8 +128,8 @@ mod deribit_inverse_swap {
         );
     }
 
-    #[test]
-    fn subscribe_candlestick() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_candlestick() {
         gen_test_subscribe_candlestick!(DeribitWSClient, &vec![("BTC-PERPETUAL".to_string(), 60)]);
         gen_test_subscribe_candlestick!(
             DeribitWSClient,
@@ -140,24 +144,24 @@ mod deribit_option {
     use std::sync::mpsc::{Receiver, Sender};
 
     const SYMBOLS: &'static [&str] = &[
-        "BTC-25MAR22-50000-C",
-        "BTC-25MAR22-60000-C",
+        "BTC-29APR22-50000-C",
+        "BTC-29APR22-60000-C",
         "BTC-24JUN22-40000-C",
         "BTC-24JUN22-60000-C",
     ];
 
-    #[test]
-    fn subscribe() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe() {
         gen_test_code!(
             DeribitWSClient,
             subscribe,
-            &vec!["trades.option.any.100ms".to_string()]
+            &vec![("trades.option.SYMBOL.100ms".to_string(), "any".to_string())]
         );
     }
 
-    #[test]
+    #[tokio::test(flavor = "multi_thread")]
     #[ignore]
-    fn subscribe_trade() {
+    async fn subscribe_trade() {
         gen_test_code!(
             DeribitWSClient,
             subscribe_trade,
@@ -168,8 +172,8 @@ mod deribit_option {
         );
     }
 
-    #[test]
-    fn subscribe_ticker() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_ticker() {
         gen_test_code!(
             DeribitWSClient,
             subscribe_ticker,
@@ -180,9 +184,9 @@ mod deribit_option {
         );
     }
 
-    #[test]
+    #[tokio::test(flavor = "multi_thread")]
     #[ignore]
-    fn subscribe_orderbook() {
+    async fn subscribe_orderbook() {
         gen_test_code!(
             DeribitWSClient,
             subscribe_orderbook,
@@ -193,9 +197,9 @@ mod deribit_option {
         );
     }
 
-    #[test]
+    #[tokio::test(flavor = "multi_thread")]
     #[ignore]
-    fn subscribe_orderbook_topk() {
+    async fn subscribe_orderbook_topk() {
         gen_test_code!(
             DeribitWSClient,
             subscribe_orderbook_topk,
@@ -206,8 +210,8 @@ mod deribit_option {
         );
     }
 
-    #[test]
-    fn subscribe_candlestick() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_candlestick() {
         gen_test_subscribe_candlestick!(
             DeribitWSClient,
             SYMBOLS
