@@ -6,32 +6,36 @@ mod ftx_spot {
     use crypto_ws_client::{FtxWSClient, WSClient};
     use std::sync::mpsc::{Receiver, Sender};
 
-    #[test]
-    fn subscribe() {
-        gen_test_code!(FtxWSClient, subscribe, &vec!["trades:BTC/USD".to_string()]);
-    }
-
-    #[test]
-    fn subscribe_raw_json() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe() {
         gen_test_code!(
             FtxWSClient,
             subscribe,
+            &vec![("trades".to_string(), "BTC/USD".to_string())]
+        );
+    }
+
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_raw_json() {
+        gen_test_code!(
+            FtxWSClient,
+            send,
             &vec![r#"{"op":"subscribe","channel":"trades","market":"BTC/USD"}"#.to_string()]
         );
     }
 
-    #[test]
-    fn subscribe_trade() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_trade() {
         gen_test_code!(FtxWSClient, subscribe_trade, &vec!["BTC/USD".to_string()]);
     }
 
-    #[test]
-    fn subscribe_bbo() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_bbo() {
         gen_test_code!(FtxWSClient, subscribe_bbo, &vec!["BTC/USD".to_string()]);
     }
 
-    #[test]
-    fn subscribe_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook() {
         gen_test_code!(
             FtxWSClient,
             subscribe_orderbook,
@@ -45,18 +49,18 @@ mod ftx_linear_swap {
     use crypto_ws_client::{FtxWSClient, WSClient};
     use std::sync::mpsc::{Receiver, Sender};
 
-    #[test]
-    fn subscribe_trade() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_trade() {
         gen_test_code!(FtxWSClient, subscribe_trade, &vec!["BTC-PERP".to_string()]);
     }
 
-    #[test]
-    fn subscribe_bbo() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_bbo() {
         gen_test_code!(FtxWSClient, subscribe_bbo, &vec!["BTC-PERP".to_string()]);
     }
 
-    #[test]
-    fn subscribe_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook() {
         gen_test_code!(
             FtxWSClient,
             subscribe_orderbook,
@@ -70,18 +74,22 @@ mod ftx_linear_future {
     use crypto_ws_client::{FtxWSClient, WSClient};
     use std::sync::mpsc::{Receiver, Sender};
 
-    #[test]
-    fn subscribe_trade() {
-        gen_test_code!(FtxWSClient, subscribe_trade, &vec!["BTC-0325".to_string()]);
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_trade() {
+        gen_test_code!(
+            FtxWSClient,
+            subscribe_trade,
+            &vec!["BTC-0325".to_string(), "BTC-0624".to_string()]
+        );
     }
 
-    #[test]
-    fn subscribe_bbo() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_bbo() {
         gen_test_code!(FtxWSClient, subscribe_bbo, &vec!["BTC-0325".to_string()]);
     }
 
-    #[test]
-    fn subscribe_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook() {
         gen_test_code!(
             FtxWSClient,
             subscribe_orderbook,
@@ -105,8 +113,8 @@ mod ftx_move {
         );
     }
 
-    #[test]
-    fn subscribe_bbo() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_bbo() {
         gen_test_code!(
             FtxWSClient,
             subscribe_bbo,
@@ -114,8 +122,8 @@ mod ftx_move {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook() {
         gen_test_code!(
             FtxWSClient,
             subscribe_orderbook,
@@ -135,13 +143,13 @@ mod ftx_bvol {
         gen_test_code!(FtxWSClient, subscribe_trade, &vec!["BVOL/USD".to_string()]);
     }
 
-    #[test]
-    fn subscribe_bbo() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_bbo() {
         gen_test_code!(FtxWSClient, subscribe_bbo, &vec!["BVOL/USD".to_string()]);
     }
 
-    #[test]
-    fn subscribe_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook() {
         gen_test_code!(
             FtxWSClient,
             subscribe_orderbook,
