@@ -6,35 +6,35 @@ mod kucoin_spot {
     use crypto_ws_client::{KuCoinSpotWSClient, WSClient};
     use std::sync::mpsc::{Receiver, Sender};
 
-    #[test]
-    fn subscribe() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe() {
         gen_test_code!(
             KuCoinSpotWSClient,
             subscribe,
-            &vec!["/market/match:BTC-USDT".to_string()]
+            &vec![("/market/match".to_string(), "BTC-USDT".to_string())]
         );
     }
 
-    #[test]
-    fn subscribe_all_bbo() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_all_bbo() {
         gen_test_code!(
             KuCoinSpotWSClient,
             subscribe,
-            &vec!["/market/ticker:all".to_string()]
+            &vec![("/market/ticker".to_string(), "all".to_string())]
         );
     }
 
-    #[test]
-    fn subscribe_raw_json() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_raw_json() {
         gen_test_code!(
             KuCoinSpotWSClient,
-            subscribe,
+            send,
             &vec![r#"{"id":"crypto-ws-client","type":"subscribe","topic":"/market/match:BTC-USDT","privateChannel":false,"response":true}"#.to_string()]
         );
     }
 
-    #[test]
-    fn subscribe_trade() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_trade() {
         gen_test_code!(
             KuCoinSpotWSClient,
             subscribe_trade,
@@ -42,8 +42,8 @@ mod kucoin_spot {
         );
     }
 
-    #[test]
-    fn subscribe_bbo() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_bbo() {
         gen_test_code!(
             KuCoinSpotWSClient,
             subscribe_bbo,
@@ -51,8 +51,8 @@ mod kucoin_spot {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook() {
         gen_test_code!(
             KuCoinSpotWSClient,
             subscribe_orderbook,
@@ -60,8 +60,8 @@ mod kucoin_spot {
         );
     }
 
-    #[test]
-    fn subscribe_l3_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_l3_orderbook() {
         gen_test_code!(
             KuCoinSpotWSClient,
             subscribe_l3_orderbook,
@@ -69,8 +69,8 @@ mod kucoin_spot {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook_topk() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook_topk() {
         gen_test_code!(
             KuCoinSpotWSClient,
             subscribe_orderbook_topk,
@@ -78,8 +78,8 @@ mod kucoin_spot {
         );
     }
 
-    #[test]
-    fn subscribe_ticker() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_ticker() {
         gen_test_code!(
             KuCoinSpotWSClient,
             subscribe_ticker,
@@ -87,8 +87,8 @@ mod kucoin_spot {
         );
     }
 
-    #[test]
-    fn subscribe_candlestick() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_candlestick() {
         gen_test_subscribe_candlestick!(KuCoinSpotWSClient, &vec![("BTC-USDT".to_string(), 60)]);
         gen_test_subscribe_candlestick!(
             KuCoinSpotWSClient,
@@ -102,26 +102,35 @@ mod kucoin_inverse_swap {
     use crypto_ws_client::{KuCoinSwapWSClient, WSClient};
     use std::sync::mpsc::{Receiver, Sender};
 
-    #[test]
-    fn subscribe() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe,
-            &vec!["/contractMarket/execution:XBTUSDM".to_string()]
+            &vec![
+                (
+                    "/contractMarket/execution".to_string(),
+                    "XBTUSDM".to_string()
+                ),
+                (
+                    "/contractMarket/execution".to_string(),
+                    "ETHUSDM".to_string()
+                )
+            ]
         );
     }
 
-    #[test]
-    fn subscribe_raw_json() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_raw_json() {
         gen_test_code!(
             KuCoinSwapWSClient,
-            subscribe,
+            send,
             &vec![r#"{"id":"crypto-ws-client","type":"subscribe","topic":"/contractMarket/execution:XBTUSDM","privateChannel":false,"response":true}"#.to_string()]
         );
     }
 
-    #[test]
-    fn subscribe_trade() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_trade() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_trade,
@@ -129,8 +138,8 @@ mod kucoin_inverse_swap {
         );
     }
 
-    #[test]
-    fn subscribe_bbo() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_bbo() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_bbo,
@@ -138,8 +147,8 @@ mod kucoin_inverse_swap {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_orderbook,
@@ -147,8 +156,8 @@ mod kucoin_inverse_swap {
         );
     }
 
-    #[test]
-    fn subscribe_l3_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_l3_orderbook() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_l3_orderbook,
@@ -156,8 +165,8 @@ mod kucoin_inverse_swap {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook_topk() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook_topk() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_orderbook_topk,
@@ -165,8 +174,8 @@ mod kucoin_inverse_swap {
         );
     }
 
-    #[test]
-    fn subscribe_ticker() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_ticker() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_ticker,
@@ -174,9 +183,9 @@ mod kucoin_inverse_swap {
         );
     }
 
-    #[test]
     #[ignore]
-    fn subscribe_candlestick() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_candlestick() {
         gen_test_subscribe_candlestick!(
             KuCoinSwapWSClient,
             &vec![("XBTUSDM".to_string(), 60), ("ETHUSDM".to_string(), 60)]
@@ -196,26 +205,29 @@ mod kucoin_linear_swap {
     use crypto_ws_client::{KuCoinSwapWSClient, WSClient};
     use std::sync::mpsc::{Receiver, Sender};
 
-    #[test]
-    fn subscribe() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe,
-            &vec!["/contractMarket/execution:XBTUSDTM".to_string()]
+            &vec![(
+                "/contractMarket/execution".to_string(),
+                "XBTUSDTM".to_string()
+            )]
         );
     }
 
-    #[test]
-    fn subscribe_raw_json() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_raw_json() {
         gen_test_code!(
             KuCoinSwapWSClient,
-            subscribe,
+            send,
             &vec![r#"{"id":"crypto-ws-client","type":"subscribe","topic":"/contractMarket/execution:XBTUSDTM","privateChannel":false,"response":true}"#.to_string()]
         );
     }
 
-    #[test]
-    fn subscribe_trade() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_trade() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_trade,
@@ -223,8 +235,8 @@ mod kucoin_linear_swap {
         );
     }
 
-    #[test]
-    fn subscribe_bbo() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_bbo() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_bbo,
@@ -232,8 +244,8 @@ mod kucoin_linear_swap {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_orderbook,
@@ -241,8 +253,8 @@ mod kucoin_linear_swap {
         );
     }
 
-    #[test]
-    fn subscribe_l3_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_l3_orderbook() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_l3_orderbook,
@@ -250,8 +262,8 @@ mod kucoin_linear_swap {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook_topk() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook_topk() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_orderbook_topk,
@@ -259,8 +271,8 @@ mod kucoin_linear_swap {
         );
     }
 
-    #[test]
-    fn subscribe_ticker() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_ticker() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_ticker,
@@ -268,9 +280,9 @@ mod kucoin_linear_swap {
         );
     }
 
-    #[test]
     #[ignore]
-    fn subscribe_candlestick() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_candlestick() {
         gen_test_subscribe_candlestick!(
             KuCoinSwapWSClient,
             &vec![("XBTUSDTM".to_string(), 60), ("ETHUSDTM".to_string(), 60)]
@@ -290,29 +302,32 @@ mod kucoin_inverse_future {
     use crypto_ws_client::{KuCoinSwapWSClient, WSClient};
     use std::sync::mpsc::{Receiver, Sender};
 
-    #[test]
     #[ignore]
-    fn subscribe() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe,
-            &vec!["/contractMarket/execution:XBTMH22".to_string()]
+            &vec![(
+                "/contractMarket/execution".to_string(),
+                "XBTMH22".to_string()
+            )]
         );
     }
 
-    #[test]
     #[ignore]
-    fn subscribe_raw_json() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_raw_json() {
         gen_test_code!(
             KuCoinSwapWSClient,
-            subscribe,
+            send,
             &vec![r#"{"id":"crypto-ws-client","type":"subscribe","topic":"/contractMarket/execution:XBTMH22","privateChannel":false,"response":true}"#.to_string()]
         );
     }
 
-    #[test]
     #[ignore]
-    fn subscribe_trade() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_trade() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_trade,
@@ -320,9 +335,9 @@ mod kucoin_inverse_future {
         );
     }
 
-    #[test]
     #[ignore]
-    fn subscribe_bbo() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_bbo() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_bbo,
@@ -330,8 +345,8 @@ mod kucoin_inverse_future {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_orderbook,
@@ -339,8 +354,8 @@ mod kucoin_inverse_future {
         );
     }
 
-    #[test]
-    fn subscribe_l3_orderbook() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_l3_orderbook() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_l3_orderbook,
@@ -348,8 +363,8 @@ mod kucoin_inverse_future {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook_topk() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_orderbook_topk() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_orderbook_topk,
@@ -357,8 +372,8 @@ mod kucoin_inverse_future {
         );
     }
 
-    #[test]
-    fn subscribe_ticker() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_ticker() {
         gen_test_code!(
             KuCoinSwapWSClient,
             subscribe_ticker,
@@ -366,9 +381,9 @@ mod kucoin_inverse_future {
         );
     }
 
-    #[test]
     #[ignore]
-    fn subscribe_candlestick() {
+    #[tokio::test(flavor = "multi_thread")]
+    async fn subscribe_candlestick() {
         gen_test_subscribe_candlestick!(KuCoinSwapWSClient, &vec![("XBTMH22".to_string(), 60)]);
         gen_test_subscribe_candlestick!(KuCoinSwapWSClient, &vec![("XBTMH22".to_string(), 604800)]);
     }
